summaryrefslogtreecommitdiff
path: root/scripts/buildtests.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/buildtests.sh')
-rwxr-xr-xscripts/buildtests.sh9
1 files changed, 7 insertions, 2 deletions
diff --git a/scripts/buildtests.sh b/scripts/buildtests.sh
index 11d13ea0..7e12781a 100755
--- a/scripts/buildtests.sh
+++ b/scripts/buildtests.sh
@@ -10,8 +10,13 @@ set -o pipefail
#ensure parallel builds
export MAKEFLAGS=-j8
-#needed to find homebrew's libffi on osx
-export PKG_CONFIG_PATH=/usr/local/opt/libffi/lib/pkgconfig
+if (test "`uname -s`" = "Darwin")
+then
+ #needed to find homebrew's libxml2 and libffi on osx
+ export PKG_CONFIG_PATH=/usr/local/opt/libffi/lib/pkgconfig:/usr/local/opt/libxml2/lib/pkgconfig
+ #needed to find the homebrew installed xml2 catalog
+ export XML_CATALOG_FILES=/usr/local/etc/xml/catalog
+fi
##### START FUNCTIONS #####